package com.example.hangman;

import java.util.Random;

import android.app.Activity;
import android.content.res.Resources;
import android.graphics.Color;
import android.os.Bundle;
import android.view.Gravity;
import android.view.ViewGroup.LayoutParams;
import android.widget.GridView;
import android.widget.LinearLayout;
import android.widget.TextView;

/**
 * This is demo code to accompany the Mobiletuts+ tutorial:
 * - Android SDK: Create a Hangman Game
 * 
 * Sue Smith - January 2014
 */

public class GameActivity extends Activity {

	//the words
	private String[] words;
	//random for word selection
	private Random rand;
	//store the current word
	private String currWord;
	//the layout holding the answer
	private LinearLayout wordLayout;
	//text views for each letter in the answer
	private TextView[] charViews;
	//letter button grid
	private GridView letters;
	//letter button adapter
	private LetterAdapter ltrAdapt;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_game);

		//read answer words in
		Resources res = getResources();
		words = res.getStringArray(R.array.words);

		//initialize random
		rand = new Random();
		//initialize word
		currWord="";

		//get answer area
		wordLayout = (LinearLayout)findViewById(R.id.word);

		//get letter button grid
		letters = (GridView)findViewById(R.id.letters);

		//start gameplay
		playGame();

	}

	//play a new game
	private void playGame(){

		//choose a word
		String newWord = words[rand.nextInt(words.length)];
		//make sure not same word as last time
		while(newWord.equals(currWord)) newWord = words[rand.nextInt(words.length)];
		//update current word
		currWord = newWord;

		//create new array for character text views
		charViews = new TextView[currWord.length()];

		//remove any existing letters
		wordLayout.removeAllViews();

		//loop through characters
		for(int c=0; c<currWord.length(); c++){
			charViews[c] = new TextView(this);
			//set the current letter
			charViews[c].setText(""+currWord.charAt(c));
			//set layout
			charViews[c].setLayoutParams(new LayoutParams(LayoutParams.WRAP_CONTENT, 
					LayoutParams.WRAP_CONTENT));
			charViews[c].setGravity(Gravity.CENTER);
			charViews[c].setTextColor(Color.WHITE);
			charViews[c].setBackgroundResource(R.drawable.letter_bg);
			//add to display
			wordLayout.addView(charViews[c]);
		}

		//reset adapter
		ltrAdapt=new LetterAdapter(this);
		letters.setAdapter(ltrAdapt);
	}

}
